/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998-1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* ===== console.css ====================================================
  == Styles used by the Error Console window.
  ======================================================================= */

/* View buttons */
@import "chrome://global/skin/viewbuttons.css";






@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

.console-box {
  background-color: -moz-Field;
  color: -moz-FieldText;
  overflow: auto;
}
 
/* ::::: console rows ::::: */

.console-row {
  border-bottom: 1px solid #A3A3A3;
  padding: 4px;
}

.console-row-file {
  color: #505050;
}


.console-row-msg > label {
  font-weight: bold;
}

.console-row-msg > label, .comsole-row-msg > description, .console-error-msg, .console-row-file, .console-row-code {
  margin: 2px;
}

.console-row-file > label {
  margin: 0;
}

.console-msg-text {
  white-space: pre-wrap !important;
}
.console-icon {
  list-style-image: inherit;
  padding-right: 6px;
  padding-left: 6px;
}

.text-link {
  text-decoration: none;  
}

.text-link:hover {
  text-decoration: underline;
}

/* ..... error rows ..... */

.console-row-code {
  color: #0000BB;
  font-size: larger;
}

.console-dots, 
.console-caret {
  height: 9px;
}

.console-dots {
  background: url("chrome://global/skin/console/console-error-dash.gif") repeat-x top;
}

.console-caret {
  width: 7px;
  background: url("chrome://global/skin/console/console-error-caret.gif") no-repeat top;
}

/* ..... message rows ..... */

.console-row[type="message"] {
  font-family: monospace;
} 

/* ..... selected state ..... */

.console-row[selected="true"] {
  background-color: #3D80DF !important;
  color: #FFF;
}

.console-row-code[selected="true"],
.console-row-content[selected="true"] > .console-row-file,
.console-row-content[selected="true"] > .console-row-file > .console-error-source > .text-link {
  color: #FFF !important;  
}

/* ::::: row colors ::::: */

.console-row[type="error"],
.console-row[type="exception"] {
  background-color: #FFD0DC;
}

.console-row[type="warning"] {
  background-color: #F8F3CC;
}

.console-row[type="message"] {
  background-color: #D3EDFF;
}

/* ::::: toolbars ::::: */

#ToolbarEval {
  -moz-appearance: none;
  background: -moz-linear-gradient(top, #E8E8E8, #D0D0D0) repeat-x;
  border-bottom: 1px solid #888;
  padding: 2px;
}

#ToolbarEval > label {
  font-weight: bold;
  color: #6D6D6D;
}

#TextfieldEval {
  margin: 2px !important;
}

#ButtonEval {
  margin: 0 4px;
  padding: 1px 10px;
  -moz-appearance: none;
  border-radius: 10000px;
  border: 1px solid rgba(0, 0, 0, .4);
  background: -moz-linear-gradient(top, #FFF, #CACACA) repeat-x;
  box-shadow: 0 1px rgba(255, 255, 255, .4);
}

#ButtonEval > .toolbarbutton-text {
  margin: 0 !important;
}

#ButtonEval:hover:active {
  text-shadow: 0 1px rgba(255, 255, 255, .4);
  background: #CCC;
  box-shadow: inset 0 1px 3px rgba(0, 0, 0, .2), 0 1px rgba(255, 255, 255, .4);
}

toolbarseparator {
  min-height: 1em;
  background-image: none;
}

/* Toolbar icons */

#ToolbarMode {
  -moz-box-pack: center;
}

#ToolbarMode toolbarbutton > .toolbarbutton-icon {
  display: none;
}

#Console\:clear {
  -moz-box-orient: vertical;
  -moz-box-align: center;
  -moz-appearance: toolbarbutton;
  font: menu;
  text-shadow: 0 1px rgba(255, 255, 255, .4);
  margin: 4px 0 9px;
  padding: 0 1px;
}
